@@ -1,6 +1,6 @@
 from zope import component
 from hurry.resource.interfaces import ICurrentNeededInclusions
-from hurry.resource import Library, ResourceInclusion
+from hurry.resource import Library, ResourceInclusion, bottom
 
 foo = Library("foo")
 
@@ -17,3 +17,10 @@ class TestMultiple(object):
     def widget(self):
         b.need()
         return "the widget HTML itself"
+
+class TestBottom(object):
+    def widget(self):
+        b.need()
+        bottom(force=True)
+        return "the widget HTML itself"
+
